@@ -17,22 +17,21 @@
 
 package org.apache.eventmesh.common.utils;
 
-import org.junit.Assert;
-import org.junit.Test;
-import org.junit.contrib.java.lang.system.EnvironmentVariables;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
+import org.junitpioneer.jupiter.SetEnvironmentVariable;
 
 public class IPUtilsTest {
 
     @Test
+    @SetEnvironmentVariable(key = "docker_host_ip", value = "dockHostIP")
     public void testDockerIP() {
-        EnvironmentVariables environmentVariables = new EnvironmentVariables();
-        environmentVariables.set("docker_host_ip", "dockHostIP");
-        Assert.assertEquals("dockHostIP", IPUtils.getLocalAddress());
+        Assertions.assertEquals("dockHostIP", IPUtils.getLocalAddress());
     }
 
     @Test
     public void testLocalhostIP() {
-        Assert.assertNotNull(IPUtils.getLocalAddress());
+        Assertions.assertNotNull(IPUtils.getLocalAddress());
     }
 
 }
