@@ -22,12 +22,6 @@ package org.apache.eventmesh.metrics.prometheus.utils;
  */
 public class PrometheusExporterConstants {
 
-    public static final String HTTP = "HTTP";
-
-    public static final String GRPC = "GRPC";
-
-    public static final String TCP = "TCP";
-
     public static final String METRICS_GRPC_PREFIX = "eventmesh.grpc.";
 
     public static final String METRICS_TCP_PREFIX = "eventmesh.tcp.";
