@@ -17,11 +17,17 @@
 
 package org.apache.eventmesh.openconnect.api.config;
 
+import org.apache.eventmesh.openconnect.offsetmgmt.api.config.OffsetStorageConfig;
+
 import lombok.Data;
+import lombok.EqualsAndHashCode;
 
 @Data
+@EqualsAndHashCode(callSuper = true)
 public abstract class SourceConfig extends Config {
 
     private PubSubConfig pubSubConfig;
 
+    private OffsetStorageConfig offsetStorageConfig;
+
 }
