@@ -17,12 +17,17 @@
 
 package org.apache.eventmesh.runtime.core.protocol.tcp.client.group;
 
+import org.apache.eventmesh.api.meta.config.EventMeshMetaConfig;
 import org.apache.eventmesh.common.protocol.SubscriptionItem;
 import org.apache.eventmesh.common.protocol.SubscriptionMode;
 import org.apache.eventmesh.common.protocol.tcp.UserAgent;
+import org.apache.eventmesh.common.utils.JsonUtils;
+import org.apache.eventmesh.common.utils.LogUtils;
 import org.apache.eventmesh.common.utils.ThreadUtils;
 import org.apache.eventmesh.runtime.boot.EventMeshTCPServer;
 import org.apache.eventmesh.runtime.constants.EventMeshConstants;
+import org.apache.eventmesh.runtime.core.consumergroup.ConsumerGroupMetadata;
+import org.apache.eventmesh.runtime.core.consumergroup.ConsumerGroupTopicMetadata;
 import org.apache.eventmesh.runtime.core.protocol.tcp.client.EventMeshTcp2Client;
 import org.apache.eventmesh.runtime.core.protocol.tcp.client.group.dispatch.DownstreamDispatchStrategy;
 import org.apache.eventmesh.runtime.core.protocol.tcp.client.group.dispatch.FreePriorityDispatchStrategy;
@@ -38,8 +43,10 @@ import org.apache.commons.collections4.MapUtils;
 import java.lang.ref.WeakReference;
 import java.net.InetSocketAddress;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.Map;
 import java.util.Objects;
+import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.TimeUnit;
 
@@ -58,10 +65,16 @@ public class ClientSessionGroupMapping {
 
     private final ConcurrentHashMap<InetSocketAddress, Session> sessionTable = new ConcurrentHashMap<>();
 
-    private final ConcurrentHashMap<String /** subsystem eg . 5109 or 5109-1A0 */, ClientGroupWrapper> clientGroupMap =
+    /**
+     * key: subsystem eg . 5109 or 5109-1A0
+     */
+    private final ConcurrentHashMap<String, ClientGroupWrapper> clientGroupMap =
         new ConcurrentHashMap<String, ClientGroupWrapper>();
 
-    private final ConcurrentHashMap<String /** subsystem eg . 5109 or 5109-1A0 */, Object> lockMap =
+    /**
+     * key: subsystem eg . 5109 or 5109-1A0
+     */
+    private final ConcurrentHashMap<String, Object> lockMap =
         new ConcurrentHashMap<String, Object>();
 
     private EventMeshTCPServer eventMeshTCPServer;
@@ -131,7 +144,7 @@ public class ClientSessionGroupMapping {
 
         closeSession(session);
 
-        //remove session from sessionTable
+        // remove session from sessionTable
         sessionTable.remove(addr);
 
         SESSION_LOGGER.info("session|close|succeed|user={}", session.getClient());
@@ -144,7 +157,7 @@ public class ClientSessionGroupMapping {
             return;
         }
 
-        //session must be synchronized to avoid SessionState be confound, for example adding subscribe when session closing
+        // session must be synchronized to avoid SessionState be confound, for example adding subscribe when session closing
         synchronized (session) {
 
             if (SessionState.CLOSED == session.getSessionState()) {
@@ -154,12 +167,20 @@ public class ClientSessionGroupMapping {
 
             session.setSessionState(SessionState.CLOSED);
 
-            if (EventMeshConstants.PURPOSE_SUB.equals(session.getClient().getPurpose())) {
-                cleanClientGroupWrapperByCloseSub(session);
-            } else if (EventMeshConstants.PURPOSE_PUB.equals(session.getClient().getPurpose())) {
-                cleanClientGroupWrapperByClosePub(session);
-            } else {
-                log.error("client purpose config is error:{}", session.getClient().getPurpose());
+            final String clientGroup = session.getClient().getGroup();
+            if (!lockMap.containsKey(clientGroup)) {
+                lockMap.putIfAbsent(clientGroup, new Object());
+            }
+            synchronized (lockMap.get(clientGroup)) {
+                if (EventMeshConstants.PURPOSE_SUB.equals(session.getClient().getPurpose())) {
+                    cleanClientGroupWrapperByCloseSub(session);
+                } else if (EventMeshConstants.PURPOSE_PUB.equals(
+                    session.getClient().getPurpose())) {
+                    cleanClientGroupWrapperByClosePub(session);
+                } else {
+                    log.error("client purpose config is error:{}",
+                        session.getClient().getPurpose());
+                }
             }
 
             if (session.getContext() != null) {
@@ -292,7 +313,8 @@ public class ClientSessionGroupMapping {
      * @param session
      */
     private void handleUnackMsgsInSession(Session session) {
-        ConcurrentHashMap<String /** seq */, DownStreamMsgContext> unAckMsg = session.getPusher().getUnAckMsg();
+        // key: seq
+        ConcurrentHashMap<String, DownStreamMsgContext> unAckMsg = session.getPusher().getUnAckMsg();
         ClientGroupWrapper clientGroupWrapper = Objects.requireNonNull(session.getClientGroupWrapper().get());
         if (unAckMsg.size() > 0 && !clientGroupWrapper.getGroupConsumerSessions().isEmpty()) {
             for (Map.Entry<String, DownStreamMsgContext> entry : unAckMsg.entrySet()) {
@@ -349,7 +371,6 @@ public class ClientSessionGroupMapping {
         }
     }
 
-
     private void shutdownClientGroupProducer(ClientGroupWrapper clientGroupWrapper) throws Exception {
         if (clientGroupWrapper.getProducerStarted().get()) {
             clientGroupWrapper.shutdownProducer();
@@ -357,15 +378,13 @@ public class ClientSessionGroupMapping {
     }
 
     private void initSessionCleaner() {
-        eventMeshTCPServer.getScheduler().scheduleAtFixedRate(
+        eventMeshTCPServer.getTcpThreadPoolGroup().getScheduler().scheduleAtFixedRate(
             () -> {
                 for (Session tmp : sessionTable.values()) {
-                    if (System.currentTimeMillis() - tmp.getLastHeartbeatTime()
-                        > eventMeshTCPServer.getEventMeshTCPConfiguration().getEventMeshTcpSessionExpiredInMills()) {
+                    long interval = System.currentTimeMillis() - tmp.getLastHeartbeatTime();
+                    if (interval > eventMeshTCPServer.getEventMeshTCPConfiguration().getEventMeshTcpSessionExpiredInMills()) {
                         try {
-                            if (log.isWarnEnabled()) {
-                                log.warn("clean expired session,client:{}", tmp.getClient());
-                            }
+                            LogUtils.warn(log, "clean expired session,client:{}", tmp.getClient());
                             closeSession(tmp.getContext());
                         } catch (Exception e) {
                             log.error("say goodbye to session error! {}", tmp, e);
@@ -376,10 +395,10 @@ public class ClientSessionGroupMapping {
     }
 
     private void initDownStreamMsgContextCleaner() {
-        eventMeshTCPServer.getScheduler().scheduleAtFixedRate(
+        eventMeshTCPServer.getTcpThreadPoolGroup().getScheduler().scheduleAtFixedRate(
             () -> {
 
-                //scan non-broadcast msg
+                // scan non-broadcast msg
                 for (Session tmp : sessionTable.values()) {
                     for (Map.Entry<String, DownStreamMsgContext> entry : tmp.getPusher().getUnAckMsg().entrySet()) {
                         String seqKey = entry.getKey();
@@ -396,7 +415,6 @@ public class ClientSessionGroupMapping {
             }, 1000, 5 * 1000, TimeUnit.MILLISECONDS);
     }
 
-
     public void init() throws Exception {
         initSessionCleaner();
         initDownStreamMsgContextCleaner();
@@ -412,7 +430,7 @@ public class ClientSessionGroupMapping {
         for (ClientGroupWrapper clientGroupWrapper : clientGroupMap.values()) {
             for (Session subSession : clientGroupWrapper.getGroupConsumerSessions()) {
                 try {
-                    EventMeshTcp2Client.serverGoodby2Client(eventMeshTCPServer, subSession, this);
+                    EventMeshTcp2Client.serverGoodby2Client(eventMeshTCPServer.getTcpThreadPoolGroup(), subSession, this);
                 } catch (Exception e) {
                     log.error("say goodbye to subSession error! {}", subSession, e);
                 }
@@ -420,7 +438,7 @@ public class ClientSessionGroupMapping {
 
             for (Session pubSession : clientGroupWrapper.getGroupProducerSessions()) {
                 try {
-                    EventMeshTcp2Client.serverGoodby2Client(eventMeshTCPServer, pubSession, this);
+                    EventMeshTcp2Client.serverGoodby2Client(eventMeshTCPServer.getTcpThreadPoolGroup(), pubSession, this);
                 } catch (Exception e) {
                     log.error("say goodbye to pubSession error! {}", pubSession, e);
                 }
@@ -434,7 +452,7 @@ public class ClientSessionGroupMapping {
 
         sessionTable.values().parallelStream().forEach(itr -> {
             try {
-                EventMeshTcp2Client.serverGoodby2Client(this.eventMeshTCPServer, itr, this);
+                EventMeshTcp2Client.serverGoodby2Client(this.eventMeshTCPServer.getTcpThreadPoolGroup(), itr, this);
             } catch (Exception e) {
                 log.error("say goodbye to session error! {}", itr, e);
             }
@@ -482,4 +500,48 @@ public class ClientSessionGroupMapping {
 
         return result;
     }
+
+    public void updateMetaData() {
+        if (!eventMeshTCPServer.getEventMeshTCPConfiguration().isEventMeshServerMetaStorageEnable()) {
+            return;
+        }
+        try {
+            Map<String, String> metadata = new HashMap<>(1 << 4);
+
+            for (Map.Entry<String, ClientGroupWrapper> clientGroupWrapperMap : this.clientGroupMap.entrySet()) {
+                String group = clientGroupWrapperMap.getKey();
+                ClientGroupWrapper cgw = clientGroupWrapperMap.getValue();
+                ConsumerGroupMetadata consumerGroupMetadata = new ConsumerGroupMetadata();
+                consumerGroupMetadata.setConsumerGroup(group);
+                Map<String, ConsumerGroupTopicMetadata> consumerGroupTopicMetadataMap =
+                    new HashMap<>(1 << 4);
+                Map<String, Map<String, Session>> topic2sessionInGroupMapping = cgw.getTopic2sessionInGroupMapping();
+                for (Map.Entry<String, Map<String, Session>> topicSessionMap : topic2sessionInGroupMapping.entrySet()) {
+                    String topic = topicSessionMap.getKey();
+                    Map<String, Session> sessionMap = topicSessionMap.getValue();
+
+                    ConsumerGroupTopicMetadata consumerGroupTopicMetadata = new ConsumerGroupTopicMetadata();
+                    consumerGroupTopicMetadata.setConsumerGroup(group);
+                    consumerGroupTopicMetadata.setTopic(topic);
+                    Set<String> sessionSet = new HashSet<>();
+                    for (Map.Entry<String, Session> sessionEntry : sessionMap.entrySet()) {
+                        String sessionId = sessionEntry.getKey();
+                        Session session = sessionEntry.getValue();
+                        sessionSet.add(session.toString());
+                    }
+                    consumerGroupTopicMetadata.setUrls(sessionSet);
+                    consumerGroupTopicMetadataMap.put(topic, consumerGroupTopicMetadata);
+                }
+
+                consumerGroupMetadata.setConsumerGroupTopicMetadataMap(consumerGroupTopicMetadataMap);
+                metadata.put(group, JsonUtils.toJSONString(consumerGroupMetadata));
+            }
+            metadata.put(EventMeshMetaConfig.EVENT_MESH_PROTO, "tcp");
+
+            eventMeshTCPServer.getMetaStorage().updateMetaData(metadata);
+
+        } catch (Exception e) {
+            log.error("update eventmesh metadata error", e);
+        }
+    }
 }
