@@ -213,7 +213,7 @@ public class ConsumeMessageConcurrentlyService implements ConsumeMessageService
                 this.submitConsumeRequestLater(consumeRequest);
             }
         } else {
-            for (int total = 0; total < msgs.size(); ) {
+            for (int total = 0; total < msgs.size();) {
                 List<MessageExt> msgThis = new ArrayList<>(consumeBatchSize);
                 for (int i = 0; i < consumeBatchSize; i++, total++) {
                     if (total < msgs.size()) {
@@ -327,7 +327,6 @@ public class ConsumeMessageConcurrentlyService implements ConsumeMessageService
         }
     }
 
-
     public ConsumerStatsManager getConsumerStatsManager() {
         return this.defaultMQPushConsumerImpl.getConsumerStatsManager();
     }
@@ -348,8 +347,7 @@ public class ConsumeMessageConcurrentlyService implements ConsumeMessageService
     private void submitConsumeRequestLater(
         final List<MessageExt> msgs,
         final ProcessQueue processQueue,
-        final MessageQueue messageQueue
-    ) {
+        final MessageQueue messageQueue) {
 
         this.scheduledExecutorService.schedule(
             () -> ConsumeMessageConcurrentlyService.this.submitConsumeRequest(msgs, processQueue, messageQueue, true), 5000, TimeUnit.MILLISECONDS);
@@ -368,7 +366,7 @@ public class ConsumeMessageConcurrentlyService implements ConsumeMessageService
                     success = true;
                     break;
                 } catch (RejectedExecutionException e) {
-                    //ignore
+                    // ignore
                 }
             }
             if (!success) {
@@ -432,7 +430,6 @@ public class ConsumeMessageConcurrentlyService implements ConsumeMessageService
                         MessageAccessor.setConsumeStartTimeStamp(msg, String.valueOf(System.currentTimeMillis()));
                     }
 
-
                 }
                 status = ConsumeMessageConcurrentlyService.this.messageListener.consumeMessage(Collections.unmodifiableList(msgs), context);
             } catch (Throwable e) {
